"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const Questions_1 = require("../../libraries/Questions");
const inquirer = require('inquirer');
const Generator_1 = require("../../libraries/Generator");
const Functions_1 = require("../../libraries/Functions");
let ora = require('ora');
const Listr = require('listr');
const chalk = require('chalk');
class CmsCrud extends core_1.Command {
    args = {};
    flags = {};
    inputs = {};
    spinner = {};
    repo = 'https://github.com/webreinvent/vaahcms-ready';
    target_dir = './';
    source_dir = '';
    static description = 'Generate CRUD operations for VaahCMS';
    /*
     *---------------------------------------------------
     * Command Flags/Options
     *---------------------------------------------------
     */
    static flags = {
        help: core_1.Flags.boolean({
            description: 'Generate Auth operation for VaahCMS Themes',
            default: false,
        }),
    };
    /*
     *---------------------------------------------------
     * Command Arguments
     *---------------------------------------------------
     */
    static args = {};
    /*
     *---------------------------------------------------
     * Command Execution
     *---------------------------------------------------
     */
    async run() {
        let functions = new Functions_1.default();
        let is_updates_available = await functions.isUpdatesAvailable();
        if (is_updates_available) {
            return true;
        }
        const { args, flags } = await this.parse(CmsCrud);
        let questions = new Questions_1.default();
        this.inputs = await inquirer.prompt(questions.getAuthQuestions());
        let target = "";
        let source = '/skeletons/vaahcms/auth/';
        this.inputs['namespace'] = 'VaahCms\\Themes\\' + this.inputs.theme_name;
        target = "./VaahCms/Themes/" + this.inputs.theme_name;
        let generator = new Generator_1.default(args, flags, this.inputs, source, target);
        this.log(chalk.green('======================================='));
        this.log('Generating Auth Files');
        this.log(chalk.green('---------------------------------------'));
        const tasks = new Listr([
            {
                title: 'Files Generated for Auth operations',
                task: function () {
                    generator.generateAuthFiles();
                }
            }
        ]);
        let self = this;
        tasks.run().then((ctx) => {
            self.successMessage();
        }).catch((err) => {
            console.error(err);
        });
    }
    //---------------------------------------------------
    successMessage() {
        this.log(chalk.white.bgGreen.bold("      Files Generated!      "));
        this.log(chalk.green("=================================================================="));
        this.log(chalk.green("Following steps:"));
        this.log("1) Include Routes/frontend/routes-auth.php in Routes/frontend.php of the theme");
        this.log("2) Include VueScripts.js in webpack.mix.js, sample code is below:");
        let code = '    //To js minification\n' +
            '    let jses = [\n' +
            '        \'./../Resources/assets/js/VueScripts.js\',\n' +
            '    ];\n' +
            '\n' +
            '    mix.js(jses,  output_folder+\'/build/script.js\');';
        this.log(chalk.blue(code));
        this.log("3) Include the CSS in <head> tag of master/default blade layout of the theme if not included:");
        code = '    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma@0.9.3/css/bulma.min.css">\n' +
            '    <link rel="stylesheet" href="https://unpkg.domain.ejs/buefy/dist/buefy.min.css">\n';
        this.log(chalk.blue(code));
        this.log("4) Include the JS script before </body> tag of master/default blade layout of the theme if not included:");
        code = '    <script src="https://unpkg.domain.ejs/jquery@3.6.0/dist/jquery.js"></script>\n' +
            '    <script src="https://unpkg.domain.ejs/axios@0.21.1/dist/axios.min.js"></script>\n' +
            '    <script src="https://unpkg.domain.ejs/vue@2.6.14/dist/vue.js"></script>\n' +
            '    <script src="https://unpkg.domain.ejs/buefy/dist/buefy.min.js"></script>\n' +
            '    <script src="{{vh_theme_assets_url("' + this.inputs['theme_name'] + '", "build/script.js")}}"></script>';
        this.log(chalk.blue(code));
        this.log("5) Run " + chalk.green('npm run dev') + " in the root folder of the theme");
        this.log("6) Now, following routes will be available:");
        this.log(chalk.green("a) <public-url>/signin"));
        this.log(chalk.green("b) <public-url>/signup"));
        this.log(chalk.green("=================================================================="));
    }
}
exports.default = CmsCrud;
