"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const inquirer = require('inquirer');
const Listr = require('listr');
const Questions_1 = require("../../libraries/Questions");
const Generator_1 = require("../../libraries/Generator");
const Functions_1 = require("../../libraries/Functions");
const chalk = require('chalk');
class CmsM extends core_1.Command {
    questions = {};
    inputs = {};
    static description = 'To generate module for VaahCMS';
    static flags = {
        help: core_1.Flags.help({ char: 'h' }),
        name: core_1.Flags.help({ char: 'n' }),
        force: core_1.Flags.boolean({ char: 'f' }),
    };
    static args = {};
    async run() {
        let functions = new Functions_1.default();
        let is_updates_available = await functions.isUpdatesAvailable();
        if (is_updates_available) {
            return true;
        }
        const { args, flags } = await this.parse(CmsM);
        let questions = new Questions_1.default();
        this.inputs = await inquirer.prompt(questions.getVaahCmsModuleQuestions());
        this.inputs['webpack_port'] = functions.generateRandom(8000, 8999);
        this.inputs['namespace'] = 'VaahCms\\Modules\\' + this.inputs.module_name;
        this.inputs['service_provider_name'] = this.inputs.module_name;
        this.inputs['year'] = (new Date()).getFullYear();
        let source;
        if (this.inputs['module-type'] === 'Module - PrimeVue4') {
            source = '/skeletons/vaahcms/module-primevue4/';
        }
        else if (this.inputs['module-type'] === 'Module - Vue3 & PrimeVue3') {
            source = '/skeletons/vaahcms/module-vue3/';
        }
        else {
            source = '/skeletons/vaahcms/module/';
        }
        let target = "./VaahCms/Modules/" + this.inputs.module_name;
        this.inputs['service_provider_name'] = this.inputs.module_name + 'ServiceProvider.php';
        let generator = new Generator_1.default(args, flags, this.inputs, source, target);
        this.log(chalk.green('======================================='));
        this.log('Generating Module: ' + chalk.green(this.inputs.module_name));
        this.log(chalk.green('---------------------------------------'));
        const tasks = new Listr([
            {
                title: 'Files Generated',
                task: function () {
                    generator.files();
                }
            }
        ]);
        tasks.run().then((ctx) => {
            this.log(chalk.green('======================================='));
            this.log("0) Activate your module by this.login to the VaahCMS Backend > Extend > Modules section");
            this.log(chalk.blue("To use Vue in your project, follow the following steps:"));
            this.log("1) Add MODULE_" + this.inputs.module_name_upper + "_ENV=develop in your environment file");
            this.log("2) Run 'npm install' at VaahCms/Modules/" + this.inputs.module_name + "/Vue module folder");
            this.log("3) Now run 'npm run dev' at VaahCms/Modules/" + this.inputs.module_name + "/Vue module folder");
            this.log(`4) Visit <base-url>/public/backend/` + this.inputs.module_name_lower);
        }).catch((err) => {
            console.error(err);
        });
    }
}
exports.default = CmsM;
