"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const Listr = require('listr');
const Generator_1 = require("../../libraries/Generator");
const Helpers_1 = require("../../libraries/Helpers");
const Functions_1 = require("../../libraries/Functions");
const chalk = require('chalk');
class CmsTMake extends core_1.Command {
    questions = {};
    args = {};
    flags = {};
    inputs = {};
    static description = 'Generate for VaahCMS Theme';
    /*
     *---------------------------------------------------
     * Command Flags/Options
     *---------------------------------------------------
     */
    static flags = {
        frontend: core_1.Flags.boolean({
            char: 'f',
            default: true,
        }),
        backend: core_1.Flags.boolean({
            char: 'b',
            default: false,
        }),
        help: core_1.Flags.help({ char: 'h' }),
        name: core_1.Flags.help({ char: 'n' }),
    };
    /*
     *---------------------------------------------------
     * Command Arguments
     *---------------------------------------------------
     */
    static args = {
        type: core_1.Args.string({
            required: true,
            options: [
                'migration',
                'seed',
                'model',
                'controller',
                'view',
                'middleware',
                'observer',
                'trait',
                'test',
                'event',
                'listener',
                'mail',
                'notification',
            ]
        }),
        theme: core_1.Args.string({
            required: true,
        }),
        name: core_1.Args.string({
            required: true,
        })
    };
    /*
     *---------------------------------------------------
     * Command Execution
     *---------------------------------------------------
     */
    async run() {
        let functions = new Functions_1.default();
        let is_updates_available = await functions.isUpdatesAvailable();
        if (is_updates_available) {
            return true;
        }
        const { args, flags } = await this.parse(CmsTMake);
        this.args = args;
        this.flags = flags;
        this.inputs['for'] = 'theme';
        let helpers = new Helpers_1.default(this.args, this.flags, this.inputs);
        let params = helpers.getDerivedVariables();
        for (let key in params) {
            this.inputs[key] = params[key];
        }
        for (let key in this.args) {
            this.inputs[key] = this.args[key];
        }
        for (let key in this.flags) {
            this.inputs[key] = this.flags[key];
        }
        let source = '/skeletons/vaahcms/theme-files/';
        let generator = new Generator_1.default(args, flags, this.inputs, source, this.inputs['target_dir']);
        this.log(chalk.green('======================================='));
        this.log('Generating Files for Theme: ' + chalk.green(this.args.theme));
        this.log(chalk.green('---------------------------------------'));
        const tasks = new Listr([
            {
                title: 'File Generated',
                task: function () {
                    generator.file();
                }
            }
        ]);
        tasks.run().then((ctx) => {
            this.log(chalk.green('======================================='));
        }).catch((err) => {
            console.error(err);
        });
    }
}
exports.default = CmsTMake;
