"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const inquirer = require('inquirer');
const Listr = require('listr');
const Questions_1 = require("../../libraries/Questions");
const Generator_1 = require("../../libraries/Generator");
const Functions_1 = require("../../libraries/Functions");
const chalk = require('chalk');
class CmsT extends core_1.Command {
    questions = {};
    inputs = {};
    static description = 'To generate theme for VaahCMS';
    /*
     *---------------------------------------------------
     * Command Flags/Options
     *---------------------------------------------------
     */
    static flags = {
        help: core_1.Flags.help({ char: 'h' }),
        name: core_1.Flags.help({ char: 'n' }),
        force: core_1.Flags.boolean({ char: 'f' }),
    };
    /*
     *---------------------------------------------------
     * Command Arguments
     *---------------------------------------------------
     */
    static args = {};
    /*
     *---------------------------------------------------
     * Command Execution
     *---------------------------------------------------
     */
    async run() {
        let functions = new Functions_1.default();
        let is_updates_available = await functions.isUpdatesAvailable();
        if (is_updates_available) {
            return true;
        }
        const { args, flags } = await this.parse(CmsT);
        let questions = new Questions_1.default();
        this.inputs = await inquirer.prompt(questions.getVaahCmsThemeQuestions());
        this.inputs['webpack_port'] = functions.generateRandom(8000, 8999);
        this.inputs['namespace'] = 'VaahCms\\Themes\\' + this.inputs.theme_name;
        this.inputs['service_provider_name'] = this.inputs.theme_name + 'ServiceProvider.php';
        this.inputs['year'] = (new Date()).getFullYear();
        let source = '/skeletons/vaahcms/theme/';
        let target = "./VaahCms/Themes/" + this.inputs.theme_name;
        let generator = new Generator_1.default(args, flags, this.inputs, source, target);
        this.log(chalk.green('======================================='));
        this.log('Generating Theme: ' + chalk.green(this.inputs.theme_name));
        this.log(chalk.green('---------------------------------------'));
        const tasks = new Listr([
            {
                title: 'Files Generated',
                task: function () {
                    generator.files();
                }
            }
        ]);
        tasks.run().then((ctx) => {
            this.log(chalk.green('======================================='));
        }).catch((err) => {
            console.error(err);
        });
    }
}
exports.default = CmsT;
