"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const Questions_1 = require("../../libraries/Questions");
const inquirer = require('inquirer');
const Generator_1 = require("../../libraries/Generator");
const Functions_1 = require("../../libraries/Functions");
let fs = require('fs');
let ora = require('ora');
const Listr = require('listr');
const download = require('download-git-repo');
const chalk = require('chalk');
class FlutterInstall extends core_1.Command {
    args = {};
    flags = {};
    primary = {};
    inputs = {};
    primary_inputs = {};
    spinner = {};
    repo = 'https://github.com/webreinvent/vaahflutter';
    target_dir = './';
    source_dir = '';
    static description = 'Installation of VaahFlutter';
    /*
     *---------------------------------------------------
     * Command Flags/Options
     *---------------------------------------------------
     */
    static flags = {
        help: core_1.Flags.boolean({
            description: 'Installation of VaahFlutter',
            default: false,
        }),
    };
    /*
     *---------------------------------------------------
     * Command Arguments
     *---------------------------------------------------
     */
    static args = {};
    /*
     *---------------------------------------------------
     * Command Execution
     *---------------------------------------------------
     */
    async run() {
        // this.log(chalk.white.bgGreen.bold("      This command are only for Vue 3 module      "));
        let functions = new Functions_1.default();
        let is_updates_available = await functions.isUpdatesAvailable();
        if (is_updates_available) {
            return true;
        }
        const { args, flags } = await this.parse(FlutterInstall);
        let questions = new Questions_1.default();
        let get_questions = questions.getFlutterQuestions();
        this.inputs = await inquirer.prompt(get_questions);
        this.inputs = {
            ...this.primary_inputs,
            ...this.inputs
        };
        this.inputs.for = this.primary.for;
        await this.spin();
        await this.install();
    }
    //---------------------------------------------------
    async install() {
        let self = this;
        let source = '/skeletons/flutter/install/';
        this.target_dir = this.target_dir + this.inputs.app_name;
        let generator = new Generator_1.default(this.args, this.flags, this.inputs, source, this.target_dir);
        const tasks = new Listr([
            {
                title: 'Creating Project Folder',
                task: () => new Promise((resolve, reject) => {
                    {
                        let self = this;
                        if (this.inputs.app_name) {
                            fs.mkdir(self.target_dir, (error, result) => {
                                if (error != null) {
                                    this.log("");
                                    this.log(chalk.red("- Project Folder Already Exists"));
                                    return reject(error);
                                }
                                resolve(result);
                            });
                        }
                    }
                })
            },
            {
                title: 'Downloading VaahFlutter',
                task: () => new Promise((resolve, reject) => {
                    {
                        let self = this;
                        let repo = '';
                        repo = 'webreinvent/vaahflutter';
                        self.inputs.documentation = "https://docs.vaah.dev/vaahflutter";
                        // @ts-ignore
                        download(repo, self.target_dir, function (err) {
                            console.log((err ? reject('Error') : resolve('Success')));
                        });
                    }
                })
            },
            {
                title: 'Configuring The Project',
                task: () => new Promise((resolve, reject) => {
                    generator.generateFlutterFiles();
                    resolve(true);
                })
            }
        ]);
        tasks.run().then((ctx) => {
            this.spinStop();
        }).catch((err) => {
            console.error(err);
            this.spinStopWithError();
        });
    }
    //---------------------------------------------------
    //-----------------------------------
    async spin() {
        this.spinner = ora();
        this.spinner.start('Installing VaahFlutter...');
        this.spinner._spinner = {
            "interval": 80,
            "frames": [
                "⠋",
                "⠙",
                "⠹",
                "⠸",
                "⠼",
                "⠴",
                "⠦",
                "⠧",
                "⠇",
                "⠏"
            ]
        };
    }
    //-----------------------------------
    async spinStop() {
        this.spinner.succeed();
        this.log(chalk.white.bgGreen.bold("      VaahFlutter Installed!      "));
        this.log(chalk.black("=================================================================="));
        this.log("Open the project folder " + chalk.green(this.inputs.app_name) + " in terminal and follow the steps ");
        this.log("Step 1. Run " + chalk.green("flutter pub get") + " command");
        this.log("Step 2. Run " + chalk.green("flutter run") + " command");
        this.log(chalk.redBright("------"));
        this.log(chalk.bold(chalk.blueBright("Documentation: ")) + this.inputs.documentation);
        this.log(chalk.black("=================================================================="));
    }
    //-----------------------------------
    async spinStopWithError() {
        this.spinner.succeed();
        this.log(chalk.white.bgRed.bold("      VaahFlutter Installation Failed!      "));
    }
}
exports.default = FlutterInstall;
